@@ -119,6 +119,10 @@ def decorate(view_function, perm_function):
         if test:
             return view_function(*args, **kwargs)
         else:
+            # tack on the permission name to the request for better error
+            # handling since Django doesn't give you access to the
+            # PermissionDenied exception object
+            request.permission_name = perm_name
             raise PermissionDenied("You need the permission %s" % perm_name)
 
     return wrapper
